/********************************************************************************
 Author :Customer Applications Center (CAC)
         
 Date : March 2014

 File name : AD5141.c

 Description :

 Hardware plateform : ADuCM360 + AD5141	
********************************************************************************/
//Interface between AD5141 and ADuCM360
//SCLK        P1.0
//SYNC        P1.1
//SDI         P1.2
//SDO         P1.3     input
//LDAC        P0.5
//RESET       P0.6
//CPOL=0, CPHA=1

#include "ADuCM360.h"
#include "ADuCM360Driver.h"

#include <stdio.h>
#include <string.h>

#include "AD5141.h"
#include "spilib.h"
#include "ClkLib.h"
#include "DioLib.h"
#include "WdtLib.h"
#include "I2cLib.h"
#include "UrtLib.h"

void SET_SCLK()
{
	pADI_GP1->GPSET |= 0x1;                          //  Set P1.0 
}

void CLR_SCLK()
{
	pADI_GP1->GPCLR |= 0x1;                          // Clear P1.0
}

void SET_SYNC()
{
	pADI_GP1->GPSET |= 0x2;                          //  Set P1.1  
}

void CLR_SYNC()
{
	pADI_GP1->GPCLR |= 0x2;                          // Clear P1.1
}
	
void SET_SDI()
{
	pADI_GP1->GPSET |= 0x4;   											 //  Set P1.2 
}

void CLR_SDI()
{
	pADI_GP1->GPCLR |= 0x4;                         //  Clear P1.2
}

void SET_LDAC()
{
	pADI_GP0->GPSET |= 0x20;                         //  Set P0.5  
}

void CLR_LDAC()
{
	pADI_GP0->GPCLR |= 0x20;                         //  Clear P0.5
}

void SET_RESET()
{
	pADI_GP0->GPSET |= 0x40;                         //  Set P0.6   
}

void CLR_RESET()
{
	pADI_GP0->GPCLR |= 0x40;                         //  Clear P0.6
}



//********************************************************************************
// Write to IDAC data register	
//********************************************************************************

void AD5141_WriteToDAC(unsigned long ulDACValue)
{
	unsigned long SendValue = 0;
	unsigned int i = 0;
	CLR_SCLK();	
	SendValue = ulDACValue;
	CLR_SYNC();	                                 //bring SYNC low
	Delay(0x10);
 
	for(i=0;i<16;i++)
	{
	SET_SCLK();                                //SCLK rising

		if(SendValue&0x8000)
		{
		 SET_SDI();			                         //Send 1 to SDI pin
		}
		else
		{
		 CLR_SDI();			                         //Send 0 to SDI pin
		}
		Delay(0x50);		     
		CLR_SCLK();					                     //SCLK falling
		Delay(0x50);
		SendValue <<= 1;	                         //Rotate data
	}

	SET_SYNC();	                                 //bring SYNC high again
	CLR_SCLK();	
	Delay(0x50);	
}
 
 
 
//********************************************************************************
// Read to IDAC data register	
//********************************************************************************
								

unsigned long AD5141_ReadDAC(void)
{
	unsigned long ulValue = 0;
	unsigned long ulData = 0; 
	unsigned long BitIN = 0; 	 
	unsigned int i = 0;
	CLR_SYNC();	                               //bring SYNC low
	Delay(0x20);
	for(i=0;i<15;i++)
	{

	SET_SCLK();                              //SCLK rising
	Delay(0x10);

	BitIN=pADI_GP1->GPIN&0x08;               //Give the GP0IN register to BitIN, in order to input the bit P0.3
	BitIN >>=3;
	ulValue+=BitIN;

	Delay(0x40);		     
	CLR_SCLK();					                     //SCLK falling
	Delay(0x50);
	ulValue <<= 1;	                         //Rotate data
	}
	SET_SCLK();                              //SCLK rising
	Delay(0x10);

	BitIN=pADI_GP1->GPIN&0x08;               //Give the GP0IN register to BitIN, in order to input the bit P0.3
	BitIN >>=3;
	ulValue+=BitIN;

	Delay(0x40);		     
	CLR_SCLK();					                     //SCLK falling
	Delay(0x50);
	SET_SYNC();	                             //bring SYNC high again
	Delay(0x10);	
	CLR_SCLK();	
	Delay(0x10);
	ulData = ulValue;
	return ulData;
}

